summaryrefslogtreecommitdiff
path: root/internal/cli/profile_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/cli/profile_test.go')
-rw-r--r--internal/cli/profile_test.go18
1 files changed, 17 insertions, 1 deletions
diff --git a/internal/cli/profile_test.go b/internal/cli/profile_test.go
index 17a5bc6..c9b1274 100644
--- a/internal/cli/profile_test.go
+++ b/internal/cli/profile_test.go
@@ -41,6 +41,7 @@ func TestProfileImport(t *testing.T) {
t.Fatalf("failed to create source conf: %v", err)
}
+ // 1. Test importing with derived name (no explicit name argument)
app := NewApp([]string{"wg-wrap", "profile", "import", srcFile})
app.ConfigDir = profilesDir
@@ -49,11 +50,26 @@ func TestProfileImport(t *testing.T) {
t.Errorf("expected no error, got %v", err)
}
// Verify the file was actually copied
destFile := filepath.Join(profilesDir, "source.conf")
if _, err := os.Stat(destFile); os.IsNotExist(err) {
t.Errorf("expected profile to be imported to %s", destFile)
}
+
+ // 2. Test importing with explicit name argument
+ customName := "custom-vpn"
+ appCustom := NewApp([]string{"wg-wrap", "profile", "import", srcFile, customName})
+ appCustom.ConfigDir = profilesDir
+
+ err = appCustom.Route()
+ if err != nil {
+ t.Errorf("expected no error for custom name import, got %v", err)
+ }
+
+ destCustomFile := filepath.Join(profilesDir, customName+".conf")
+ if _, err := os.Stat(destCustomFile); os.IsNotExist(err) {
+ t.Errorf("expected profile to be imported to %s", destCustomFile)
+ }
}
func TestProfileDelete(t *testing.T) {
@@ -49,11 +50,26 @@ func TestProfileImport(t *testing.T) {
t.Errorf("expected no error, got %v", err)
}
- // Verify the file was actually copied
+ // Verify the file was actually copied to derived name
destFile := filepath.Join(profilesDir, "source.conf")
if _, err := os.Stat(destFile); os.IsNotExist(err) {